##################################
 How to Write a Framework Wrapper
##################################

This document is for people who want to write a framework wrapper for Aspen. If
you only want to use Aspen with an existing framework wrapper, then the
`Dispatch <dispatch.html>`_ and `Simplates <simplates.html>`_ documents should
cover what you need.
